summaryrefslogtreecommitdiffstats
path: root/chrome
diff options
context:
space:
mode:
Diffstat (limited to 'chrome')
-rw-r--r--chrome/browser/browser_main.cc4
-rw-r--r--chrome/browser/browser_main.h10
-rw-r--r--chrome/browser/extensions/extension_event_router_forwarder_unittest.cc4
-rw-r--r--chrome/browser/profiles/profile_manager.cc4
-rw-r--r--chrome/browser/profiles/profile_manager.h4
-rw-r--r--chrome/browser/profiles/profile_manager_unittest.cc4
-rw-r--r--chrome/browser/tabs/tab_strip_model_unittest.cc6
-rw-r--r--chrome/nacl/nacl_main.cc6
-rw-r--r--chrome/utility/utility_main.cc4
9 files changed, 23 insertions, 23 deletions
diff --git a/chrome/browser/browser_main.cc b/chrome/browser/browser_main.cc
index 57d3618..6f2948e 100644
--- a/chrome/browser/browser_main.cc
+++ b/chrome/browser/browser_main.cc
@@ -24,6 +24,7 @@
#include "base/string_split.h"
#include "base/string_util.h"
#include "base/sys_string_conversions.h"
+#include "base/system_monitor/system_monitor.h"
#include "base/threading/platform_thread.h"
#include "base/threading/thread_restrictions.h"
#include "base/time.h"
@@ -109,7 +110,6 @@
#include "net/url_request/url_request_throttler_manager.h"
#include "ui/base/l10n/l10n_util.h"
#include "ui/base/resource/resource_bundle.h"
-#include "ui/base/system_monitor/system_monitor.h"
#include "ui/gfx/gl/gl_implementation.h"
#include "ui/gfx/gl/gl_switches.h"
@@ -527,7 +527,7 @@ void BrowserMainParts::MainMessageLoopStart() {
main_message_loop_.reset(new MessageLoop(MessageLoop::TYPE_UI));
// TODO(viettrungluu): should these really go before setting the thread name?
- system_monitor_.reset(new ui::SystemMonitor);
+ system_monitor_.reset(new base::SystemMonitor);
hi_res_timer_manager_.reset(new HighResolutionTimerManager);
network_change_notifier_.reset(net::NetworkChangeNotifier::Create());
diff --git a/chrome/browser/browser_main.h b/chrome/browser/browser_main.h
index a867e20..09153db 100644
--- a/chrome/browser/browser_main.h
+++ b/chrome/browser/browser_main.h
@@ -20,12 +20,12 @@ class MessageLoop;
class MetricsService;
class PrefService;
-namespace net {
-class NetworkChangeNotifier;
+namespace base {
+class SystemMonitor;
}
-namespace ui {
-class SystemMonitor;
+namespace net {
+class NetworkChangeNotifier;
}
// BrowserMainParts:
@@ -166,7 +166,7 @@ class BrowserMainParts {
// Members initialized in |MainMessageLoopStart()| ---------------------------
scoped_ptr<MessageLoop> main_message_loop_;
- scoped_ptr<ui::SystemMonitor> system_monitor_;
+ scoped_ptr<base::SystemMonitor> system_monitor_;
scoped_ptr<HighResolutionTimerManager> hi_res_timer_manager_;
scoped_ptr<net::NetworkChangeNotifier> network_change_notifier_;
scoped_ptr<BrowserThread> main_thread_;
diff --git a/chrome/browser/extensions/extension_event_router_forwarder_unittest.cc b/chrome/browser/extensions/extension_event_router_forwarder_unittest.cc
index 7d82ea5..ff5f5da 100644
--- a/chrome/browser/extensions/extension_event_router_forwarder_unittest.cc
+++ b/chrome/browser/extensions/extension_event_router_forwarder_unittest.cc
@@ -5,6 +5,7 @@
#include "chrome/browser/extensions/extension_event_router_forwarder.h"
#include "base/message_loop.h"
+#include "base/system_monitor/system_monitor.h"
#include "chrome/browser/profiles/profile_manager.h"
#include "chrome/test/testing_browser_process_test.h"
#include "chrome/test/testing_profile.h"
@@ -13,7 +14,6 @@
#include "googleurl/src/gurl.h"
#include "testing/gmock/include/gmock/gmock.h"
#include "testing/gtest/include/gtest/gtest.h"
-#include "ui/base/system_monitor/system_monitor.h"
namespace {
@@ -66,7 +66,7 @@ class ExtensionEventRouterForwarderTest : public TestingBrowserProcessTest {
MessageLoopForUI message_loop_;
BrowserThread ui_thread_;
BrowserThread io_thread_;
- ui::SystemMonitor dummy;
+ base::SystemMonitor dummy;
// Profiles are weak pointers, owned by ProfileManager in |browser_process_|.
TestingProfile* profile1_;
TestingProfile* profile2_;
diff --git a/chrome/browser/profiles/profile_manager.cc b/chrome/browser/profiles/profile_manager.cc
index cee0265..dbd03de 100644
--- a/chrome/browser/profiles/profile_manager.cc
+++ b/chrome/browser/profiles/profile_manager.cc
@@ -111,7 +111,7 @@ Profile* ProfileManager::GetDefaultProfile() {
}
ProfileManager::ProfileManager() : logged_in_(false) {
- ui::SystemMonitor::Get()->AddObserver(this);
+ base::SystemMonitor::Get()->AddObserver(this);
BrowserList::AddObserver(this);
#if defined(OS_CHROMEOS)
registrar_.Add(
@@ -122,7 +122,7 @@ ProfileManager::ProfileManager() : logged_in_(false) {
}
ProfileManager::~ProfileManager() {
- ui::SystemMonitor* system_monitor = ui::SystemMonitor::Get();
+ base::SystemMonitor* system_monitor = base::SystemMonitor::Get();
if (system_monitor)
system_monitor->RemoveObserver(this);
BrowserList::RemoveObserver(this);
diff --git a/chrome/browser/profiles/profile_manager.h b/chrome/browser/profiles/profile_manager.h
index 3c2c8e7..de656d6 100644
--- a/chrome/browser/profiles/profile_manager.h
+++ b/chrome/browser/profiles/profile_manager.h
@@ -17,12 +17,12 @@
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop.h"
+#include "base/system_monitor/system_monitor.h"
#include "base/threading/non_thread_safe.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/ui/browser_list.h"
#include "content/common/notification_observer.h"
#include "content/common/notification_registrar.h"
-#include "ui/base/system_monitor/system_monitor.h"
class FilePath;
class NewProfileLauncher;
@@ -39,7 +39,7 @@ class ProfileManagerObserver {
};
class ProfileManager : public base::NonThreadSafe,
- public ui::SystemMonitor::PowerObserver,
+ public base::SystemMonitor::PowerObserver,
public BrowserList::Observer,
public NotificationObserver,
public Profile::Delegate {
diff --git a/chrome/browser/profiles/profile_manager_unittest.cc b/chrome/browser/profiles/profile_manager_unittest.cc
index 541fd59..54bcbc9 100644
--- a/chrome/browser/profiles/profile_manager_unittest.cc
+++ b/chrome/browser/profiles/profile_manager_unittest.cc
@@ -8,6 +8,7 @@
#include "base/memory/scoped_temp_dir.h"
#include "base/message_loop.h"
#include "base/path_service.h"
+#include "base/system_monitor/system_monitor.h"
#include "base/values.h"
#include "chrome/browser/prefs/browser_prefs.h"
#include "chrome/browser/profiles/profile.h"
@@ -22,7 +23,6 @@
#include "content/common/notification_service.h"
#include "testing/gmock/include/gmock/gmock.h"
#include "testing/gtest/include/gtest/gtest.h"
-#include "ui/base/system_monitor/system_monitor.h"
namespace {
// This global variable is used to check that value returned to different
@@ -61,7 +61,7 @@ class ProfileManagerTest : public TestingBrowserProcessTest {
BrowserThread ui_thread_;
BrowserThread file_thread_;
- ui::SystemMonitor system_monitor_dummy_;
+ base::SystemMonitor system_monitor_dummy_;
// Also will test profile deletion.
scoped_ptr<ProfileManager> profile_manager_;
diff --git a/chrome/nacl/nacl_main.cc b/chrome/nacl/nacl_main.cc
index 51c57b8..f2e0cbf 100644
--- a/chrome/nacl/nacl_main.cc
+++ b/chrome/nacl/nacl_main.cc
@@ -11,6 +11,7 @@
#include "base/command_line.h"
#include "base/message_loop.h"
#include "base/string_util.h"
+#include "base/system_monitor/system_monitor.h"
#include "chrome/common/chrome_constants.h"
#include "chrome/common/chrome_switches.h"
#include "chrome/common/logging_chrome.h"
@@ -21,7 +22,6 @@
#include "content/common/hi_res_timer_manager.h"
#include "content/common/main_function_params.h"
#include "content/common/result_codes.h"
-#include "ui/base/system_monitor/system_monitor.h"
#if defined(OS_WIN)
#include "chrome/nacl/broker_thread.h"
@@ -37,7 +37,7 @@ int NaClBrokerMain(const MainFunctionParams& parameters) {
MessageLoopForIO main_message_loop;
base::PlatformThread::SetName("CrNaClBrokerMain");
- ui::SystemMonitor system_monitor;
+ base::SystemMonitor system_monitor;
HighResolutionTimerManager hi_res_timer_manager;
const CommandLine& parsed_command_line = parameters.command_line_;
@@ -101,7 +101,7 @@ int NaClMain(const MainFunctionParams& parameters) {
MessageLoopForIO main_message_loop;
base::PlatformThread::SetName("CrNaClMain");
- ui::SystemMonitor system_monitor;
+ base::SystemMonitor system_monitor;
HighResolutionTimerManager hi_res_timer_manager;
#if defined(OS_WIN) || defined(OS_MACOSX) || defined(OS_LINUX)
diff --git a/chrome/utility/utility_main.cc b/chrome/utility/utility_main.cc
index 9d4a63d..d4647f0 100644
--- a/chrome/utility/utility_main.cc
+++ b/chrome/utility/utility_main.cc
@@ -4,6 +4,7 @@
#include "base/command_line.h"
#include "base/message_loop.h"
+#include "base/system_monitor/system_monitor.h"
#include "base/threading/platform_thread.h"
#include "chrome/common/chrome_paths.h"
#include "chrome/common/extensions/extension_l10n_util.h"
@@ -11,7 +12,6 @@
#include "content/common/child_process.h"
#include "content/common/hi_res_timer_manager.h"
#include "content/common/main_function_params.h"
-#include "ui/base/system_monitor/system_monitor.h"
#include "ui/base/ui_base_switches.h"
#if defined(OS_WIN)
@@ -28,7 +28,7 @@ int UtilityMain(const MainFunctionParams& parameters) {
MessageLoop main_message_loop;
base::PlatformThread::SetName("CrUtilityMain");
- ui::SystemMonitor system_monitor;
+ base::SystemMonitor system_monitor;
HighResolutionTimerManager hi_res_timer_manager;
ChildProcess utility_process;
diff --git a/chrome/browser/tabs/tab_strip_model_unittest.cc b/chrome/browser/tabs/tab_strip_model_unittest.cc
index fc1c941..3077f8c 100644
--- a/chrome/browser/tabs/tab_strip_model_unittest.cc
+++ b/chrome/browser/tabs/tab_strip_model_unittest.cc
@@ -13,6 +13,7 @@
#include "base/string_number_conversions.h"
#include "base/string_split.h"
#include "base/string_util.h"
+#include "base/system_monitor/system_monitor.h"
#include "base/utf_string_conversions.h"
#include "chrome/browser/defaults.h"
#include "chrome/browser/extensions/extension_tab_helper.h"
@@ -37,7 +38,6 @@
#include "content/common/notification_source.h"
#include "content/common/property_bag.h"
#include "testing/gtest/include/gtest/gtest.h"
-#include "ui/base/system_monitor/system_monitor.h"
using testing::_;
@@ -262,8 +262,8 @@ class TabStripModelTest : public RenderViewHostTestHarness {
std::wstring profile_path_;
std::map<TabContents*, int> foo_;
- // ProfileManager requires a ui::SystemMonitor.
- ui::SystemMonitor system_monitor;
+ // ProfileManager requires a base::SystemMonitor.
+ base::SystemMonitor system_monitor;
ProfileManager pm_;
};